# EC-Earth_patch

EC-Earth is a global coupled climate model. It is developed by a consortium of European research institutions.
The goal of this project is to adapt this model for our needs in TECLIM: install, run management, etc.

### Important Notes

**YOU MUST HAVE YOUR `~/.ssh/id_rsa.pub` FILE BEFORE STARTING TO WORK WITH GIT ON ZENOBE**.

```
mv $HOME/.ssh/config $HOME/.ssh/config_old
cat config | sed -e 's/pbarriat/'$USER'/g' > $HOME/.ssh/config

[ ! -f ~/.ssh/id_rsa.pub ] && ssh-keygen -t rsa
ssh-copy-id -i ~/.ssh/id_rsa.pub gwcism.cism.ucl.ac.be
```

## Install

First, clone the `pbarriat/ecearth_patch` repository and update your shell startup script to source the 'bashrc' file to add ecearth globals variables to your environment. For instance:
```
git clone ssh://egit/pbarriat/ecearth_patch.git
```

Then, checkout the EC-Earth SVN repository. For instance:
```
svn co https://svn.ec-earth.org/ecearth3/tags/3.2.2 ecearth_3.2.2
```

Final step, go to the `pbarriat/ecearth_patch` repository, open & adapt the `install.sh` script and run it:
```
cd ecearth_patch
./install.sh
```

## Compile & Run

First, **sign out of Zenobe** and sign in again. Then, type `configure_ecearth`.

Compile the model:

1. Go to `~/modeles/ecearth_$tag/sources` and:
```
./util/ec-conf/ec-conf -p zenobe-intel-intelmpi config-build.xml
```
2. Go to `./oasis3-mct/util/make_dir` and:
```
make BUILD_ARCH=ecconf -f TopMakefileOasis3
```
3. Go to `./ifs-36r4` and:
```
./makeifs -j 4
```
4. Go to `./xios-2` and:
```
./make_xios --prod --arch ecconf --use_oasis oasis3_mct --netcdf_lib netcdf4_par -j 4
```
5. Go to `./nemo-3.6/CONFIG` and:
```
./makenemo -n ORCA1L75_LIM3 -m ecconf -j4
```
6. Go to `./runoff-mapper/src` and:
```
make
```

For a quick classical run test:
- Go to `~/modeles/ecearth_$tag/runtime/classic` and:
```
../../sources/util/ec-conf/ec-conf -p zenobe config-run.xml
```
- Submit the script `ece-ifs+nemo.sh` to the PBS batch system:
```
qsub ece-ifs+nemo.sh
```

### Benchmarks

| XIOS | NEMO | IFS | Runoff | WTIME per YEAR | #CORES |
| ---- | ---- | --- | ------ | -------------- | ------ |
| 1    |  64  |  78 |    1   |      **5h**    |   144  |
| 2    |  64  | 196 |    2   |                |   264  |
| 2    | 128  | 348 |    2   |                |   480  |

## Contributors

- ELIC members [@pbarriat](http://www.climate.be:3000/pbarriat)

## License

This project is under the Creative Commons CC0 1.0 Universal License. See the [LICENSE](http://www.climate.be:3000/TECLIM/LOVECLIM/src/master/LICENSE) file for the full license text.